==> hledger-1.17.1.1-13-x86_64.pkg.tar.zst: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hledger
version:              1.17.1.1
visibility:           public
id:                   hledger-1.17.1.1-FeFX7rv78wlGVnOHh4zhl5
key:                  hledger-1.17.1.1-FeFX7rv78wlGVnOHh4zhl5
license:              GPL-3.0-only
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Command-line interface for the hledger accounting tool
description:
    This is hledger'\''s command-line interface.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.

    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, terminal and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.

category:             Finance, Console
abi:                  053124e1ddee740f37ca32e8cee22878
exposed:              True
exposed-modules:
    Hledger.Cli Hledger.Cli.Anon Hledger.Cli.CliOptions
    Hledger.Cli.Commands Hledger.Cli.Commands.Accounts
    Hledger.Cli.Commands.Activity Hledger.Cli.Commands.Add
    Hledger.Cli.Commands.Balance Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Checkdates
    Hledger.Cli.Commands.Checkdupes Hledger.Cli.Commands.Close
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Descriptions
    Hledger.Cli.Commands.Diff Hledger.Cli.Commands.Files
    Hledger.Cli.Commands.Help Hledger.Cli.Commands.Import
    Hledger.Cli.Commands.Incomestatement Hledger.Cli.Commands.Notes
    Hledger.Cli.Commands.Payees Hledger.Cli.Commands.Prices
    Hledger.Cli.Commands.Print Hledger.Cli.Commands.Printunique
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Registermatch
    Hledger.Cli.Commands.Rewrite Hledger.Cli.Commands.Roi
    Hledger.Cli.Commands.Stats Hledger.Cli.Commands.Tags
    Hledger.Cli.CompoundBalanceCommand Hledger.Cli.DocFiles
    Hledger.Cli.Main Hledger.Cli.Utils Hledger.Cli.Version

hidden-modules:       Paths_hledger
import-dirs:          /usr/lib/ghc-8.8.3/site-local/hledger-1.17.1.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/hledger-1.17.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger
hs-libraries:         HShledger-1.17.1.1-FeFX7rv78wlGVnOHh4zhl5
depends:
    Decimal-0.5.1-rHQ1YSMP8w3ChB6m9FMfO
    Diff-0.4.0-2mjKm06J7q93AfCNNQ75Rh
    aeson-1.4.7.1-2vh3WJvM2HmJTL8YxIIpzz
    ansi-terminal-0.10.3-E9f5lPr75erGIbzW4It0dA base-4.13.0.0
    base-compat-batteries-0.11.1-LOY5lyev4zYDDSw7XooUgP
    bytestring-0.10.10.0 cmdargs-0.10.20-3vykGHDI4u11ZYJ5Aek1JG
    containers-0.6.2.1 data-default-0.7.1.1-KwmPSgEEmCp4io60ICryCw
    directory-1.3.6.0 extra-1.7.1-8tgnQwWiTfHDrxDIquB4Of
    filepath-1.4.2.1 hashable-1.3.0.0-GFyEr4gS8CZEgl3N6WrORB
    haskeline-0.7.5.0 hledger-lib-1.17.1-5hd79vTsYRh9gt7DZ6QtRX
    lucid-2.9.12-1lPzwsDJzThJQj6GdfdxaD
    math-functions-0.3.3.0-D9HamiZAYCYJnENO998fmh
    megaparsec-8.0.0-5WXECwyMJxvIYZsEBaAJw8 mtl-2.2.2
    old-time-1.1.0.3-LFCo3WvTzIJ9XV4spupeM9 parsec-3.1.14.0
    pretty-show-1.10-7q5amcqtFPNELOrR9L3gUm process-1.6.8.0
    regex-tdfa-1.3.1.0-2thRUVc0Ew7ZsITrBIZey
    safe-0.3.18-77EtIZs3AFB4iOmOvdspYk
    shakespeare-2.0.24-4tSO4FhJqpe5q5zmc8ig2x
    split-0.2.3.4-2SLh24GWGfv9bpFm6zqb4X
    tabular-0.2.2.7-H8L3q3tfo0Y3tOiZWzAue2
    tasty-1.2.3-84jipiM8hglGk5H8KcgpxS
    temporary-1.3-BiFXPx2xjAKDOblp9pWkcg terminfo-0.4.1.4 text-1.2.4.0
    time-1.9.3 timeit-2.0-C5F3nl9E9zYIMscybjdAzR transformers-0.5.6.2
    unordered-containers-0.2.10.0-A1cNogzO5wQ33Xk0bjeyDo
    utf8-string-1.0.1.1-IRxNMq5AVf036EceEkASq3
    utility-ht-0.0.15-BdbW8uGDElU1dRwWscmf2c
    wizards-1.0.3-6ZZmIj3CU2FA1xyhcf9Ofx

haddock-interfaces:   /usr/share/doc/hledger/html/hledger.haddock
haddock-html:         /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-1.17.1.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hledger
version:              1.17.1.1
visibility:           public
id:                   hledger-1.17.1.1-GN8cx2RGkePGt2zaQ2Gt5w
key:                  hledger-1.17.1.1-GN8cx2RGkePGt2zaQ2Gt5w
license:              GPL-3.0-only
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Command-line interface for the hledger accounting tool
description:
    This is hledger'\''s command-line interface.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.

    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, terminal and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.

category:             Finance, Console
abi:                  46a574631b4e32a09334379b6513e591
exposed:              True
exposed-modules:
    Hledger.Cli Hledger.Cli.Anon Hledger.Cli.CliOptions
    Hledger.Cli.Commands Hledger.Cli.Commands.Accounts
    Hledger.Cli.Commands.Activity Hledger.Cli.Commands.Add
    Hledger.Cli.Commands.Balance Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Checkdates
    Hledger.Cli.Commands.Checkdupes Hledger.Cli.Commands.Close
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Descriptions
    Hledger.Cli.Commands.Diff Hledger.Cli.Commands.Files
    Hledger.Cli.Commands.Help Hledger.Cli.Commands.Import
    Hledger.Cli.Commands.Incomestatement Hledger.Cli.Commands.Notes
    Hledger.Cli.Commands.Payees Hledger.Cli.Commands.Prices
    Hledger.Cli.Commands.Print Hledger.Cli.Commands.Printunique
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Registermatch
    Hledger.Cli.Commands.Rewrite Hledger.Cli.Commands.Roi
    Hledger.Cli.Commands.Stats Hledger.Cli.Commands.Tags
    Hledger.Cli.CompoundBalanceCommand Hledger.Cli.DocFiles
    Hledger.Cli.Main Hledger.Cli.Utils Hledger.Cli.Version

hidden-modules:       Paths_hledger
import-dirs:          /usr/lib/ghc-8.10.1/site-local/hledger-1.17.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/hledger-1.17.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger
hs-libraries:         HShledger-1.17.1.1-GN8cx2RGkePGt2zaQ2Gt5w
depends:
    Decimal-0.5.1-BdASue6w3P84KssZFpDPYx
    Diff-0.4.0-LgEpQqtAwCxKgwuQ1EIarv
    aeson-1.4.7.1-K7SQDJO13XY25hkTSRHjwP
    ansi-terminal-0.10.3-I9d52OUfpwl8a0eWq2t9UF base-4.14.0.0
    base-compat-batteries-0.11.1-FKhdLPzlqPMEzPCOSuMlMX
    bytestring-0.10.10.0 cmdargs-0.10.20-5yLBsRitu2lKoUCxdH99aC
    containers-0.6.2.1 data-default-0.7.1.1-EsVLaVY6HCEDLB4TDfr8Af
    directory-1.3.6.0 extra-1.7.1-Eq7xWJ8nmOIIaxJNamwX5l
    filepath-1.4.2.1 hashable-1.3.0.0-1Vf2Ag4BrTJ2HvpfsDNoTB
    haskeline-0.8.0.0 hledger-lib-1.17.1-5dKjDxveIF5Irf8TKWpJjr
    lucid-2.9.12-38GhzbEEfhWFCcBoVYgHVq
    math-functions-0.3.3.0-1DFzn5WOWiV1ZCEJrlcZZH
    megaparsec-8.0.0-KpdQ9LEGN4p9QotiwOIGMX mtl-2.2.2
    old-time-1.1.0.3-JoYnfsOPb5U42beoXLbXf6 parsec-3.1.14.0
    pretty-show-1.10-5aohyDmEADG9yJ0U7kMN1J process-1.6.8.2
    regex-tdfa-1.3.1.0-HPvdYMAdCmlIUvSVzIJAm1
    safe-0.3.18-2LNtMsnnnlx63a2ppUk24A
    shakespeare-2.0.24-Ci2n8THmZ2oKDGNGGRyrTQ
    split-0.2.3.4-2D98CwebMZP9RhZUBKVJlZ
    tabular-0.2.2.7-2G81cYqDwvL63xzCtzigcl
    tasty-1.2.3-3QFWhcWYviCIxnieFsgkcX
    temporary-1.3-DsZWLnguopFBxBqIiY1Hvo terminfo-0.4.1.4 text-1.2.3.2
    time-1.9.3 timeit-2.0-G1rO4n9EY636waOAdcWrR transformers-0.5.6.2
    unordered-containers-0.2.10.0-G13aGNInC3gBl4w7zg86q
    utf8-string-1.0.1.1-L5P9SR8YxIu1NqwMrJwV7a
    utility-ht-0.0.15-KzVaAdUwP82GP9rrO9tBGk
    wizards-1.0.3-DfmGpPlUvthL5nhJvRZq3Z

haddock-interfaces:   /usr/share/doc/hledger/html/hledger.haddock
haddock-html:         /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
